AuthenticationService class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerWithEmailPass(
{required String displayName, required String email, required String password, bool sendEmailVerification = false}) → Future - Register With Email password
-
resetPassword(
String email) → Future -
sendOTPPhoneNumber(
{required String phoneNumber, Duration? timeout, required dynamic onCodeSend(String verificationId), required dynamic onError(String verificationId), dynamic onAutoVerified(PhoneAuthCredential phoneAuthCredential)?}) → Future - login With Phone number
-
signInWithEmailPass(
{required String email, required String password}) → Future - SignIn With Email and password
-
signInWithGoogle(
) → Future - SignIn With Google
-
signOut(
) → Future - Sing out
-
toString(
) → String -
A string representation of this object.
inherited
-
updatePassword(
String newPassword) → Future -
verifyPasswordResetCode(
String code) → Future
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited